package ru.ulstu.fc.project.service;

import org.springframework.stereotype.Service;
import ru.ulstu.fc.rule.model.FuzzyRule;
import ru.ulstu.fc.rule.model.dto.FuzzyRuleDto;
import ru.ulstu.fc.rule.repository.FuzzyRuleRepository;

import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

@Service
public class ProjectRulesService {
    private final FuzzyRuleRepository ruleRepository;
    private final ProjectService projectService;

    public ProjectRulesService(FuzzyRuleRepository ruleRepository,
                               ProjectService projectService) {
        this.ruleRepository = ruleRepository;
        this.projectService = projectService;
    }

    public List<FuzzyRule> getByProjectId(Integer projectId) {
        if (projectId == null || projectId == 0) {
            return Collections.emptyList();
        }
        return ruleRepository.findByProject(projectService.getById(projectId));
    }

    public List<FuzzyRuleDto> getDtoByProjectId(Integer projectId) {
        return getByProjectId(projectId).stream().map(FuzzyRuleDto::new).collect(Collectors.toList());
    }
}
